package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MapBean;
import com.bonus.canteen.core.menu.dto.LongIds;
import com.bonus.canteen.core.menu.dto.MenuDishesDTO;
import com.bonus.canteen.core.menu.dto.MenuDishesImportDTO;
import com.bonus.canteen.core.menu.dto.StringIds;
import com.bonus.canteen.core.menu.service.IMenuDishesService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.canteen.core.menu.domain.MenuDishes;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 菜品信息Controller
 *
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "菜品信息接口")
@RestController
@RequestMapping("/menu_dishes")
public class MenuDishesController extends BaseController {
    @Autowired
    private IMenuDishesService menuDishesService;

    /**
     * 查询菜品信息列表
     */
    @ApiOperation(value = "查询菜品信息列表")
    //@RequiresPermissions("menu:dishes:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody MenuDishes menuDishes) {
        startPage();
        List<MenuDishes> list = menuDishesService.selectMenuDishesList(menuDishes);
        return getDataTable(list);
    }

    /**
     * 导出菜品信息列表
     */
    @ApiOperation(value = "导出菜品信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:export")
    @SysLog(title = "菜品信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuDishes menuDishes) {
        List<MenuDishes> list = menuDishesService.selectMenuDishesList(menuDishes);
        ExcelUtil<MenuDishes> util = new ExcelUtil<MenuDishes>(MenuDishes.class);
        util.exportExcel(response, list, "菜品信息数据");
    }

    /**
     * 获取菜品信息详细信息
     */
    @ApiOperation(value = "获取菜品信息详细信息")
    @PostMapping(value = "/getInfo")
    public AjaxResult getInfo(MenuDishes menuDishes) {
        return success(menuDishesService.selectMenuDishesById(menuDishes.getId()));
    }
    @ApiOperation(value = "获取菜品信息详细信息")
    //@RequiresPermissions("menu:dishes:query")
    @PostMapping(value = "/getDishesType")
    public AjaxResult getDishesType(@RequestBody MapBean mapBean) {
        return success(menuDishesService.getDishesType(mapBean));
    }



    /**
     * 新增菜品信息
     */
    @ApiOperation(value = "新增菜品信息-已弃用")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品信息")
    @PostMapping
    public AjaxResult add(@RequestBody MenuDishes menuDishes) {
        try {
            return toAjax(menuDishesService.insertMenuDishes(menuDishes));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }
    //MenuDishesDTO

    @ApiOperation(value = "新增菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:add")
    @SysLog(title = "菜品信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品信息")
    @PostMapping("/addMenuDishes")
    public AjaxResult addMenuDishes(@RequestBody MenuDishesDTO menuDishesDTO) {
        try {
            return toAjax(menuDishesService.addMenuDishes(menuDishesDTO));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改菜品信息
     */
    @ApiOperation(value = "修改菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:edit")
    @SysLog(title = "菜品信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品信息")
    @PostMapping("/deitMenuDishes")
    public AjaxResult deitMenuDishes(@RequestBody MenuDishesDTO menuDishesDTO) {
        try {
            return toAjax(menuDishesService.updateMenuDishes(menuDishesDTO));
        } catch (Exception e) {
            return error( e.getMessage());
        }
    }

    /**
     * 删除菜品信息
     */
    @ApiOperation(value = "删除菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:remove")
    @SysLog(title = "菜品信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品信息")
	@PostMapping("/del")
    public AjaxResult remove(@RequestBody LongIds ids) {
        return toAjax(menuDishesService.deleteMenuDishesByIds(ids.getIds()));
    }

    @ApiOperation(value = "查看菜品信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:dishes:remove")
    @SysLog(title = "查看菜品信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品信息")
    @PostMapping("/check")
    public AjaxResult check(@RequestBody MenuDishesDTO menuDishesDTO) {
        return success(menuDishesService.check(menuDishesDTO));
    }


    @PostMapping({"/import/check"})
    @ApiOperation("导入之前检查数据是否可以导入")
    public AjaxResult importDishesCheck(@RequestParam("file") MultipartFile excel) {
        return AjaxResult.success(this.menuDishesService.importDishesCheck(excel));
    }


    @PostMapping({"/import/dishes"})
    @ApiOperation("导入成功的菜品信息")
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult importDishes(@RequestBody List<MenuDishesImportDTO> request) {
        return AjaxResult.success(this.menuDishesService.newImportDishes(request));
    }

}
